@@ -1,5 +1,4 @@
 from hape.logging import Logging
-
 from hape.hape_cli.controllers.init_controller import InitController
 
 class InitArgumentParser:
@@ -8,7 +7,7 @@ class InitArgumentParser:
         self.logger = Logging.get_logger('hape.hape_cli.argument_parsers.init_argument_parser')
 
     def create_subparser(self, subparsers):    
-        self.logger.debug(f"create_subparser(subparsers: {subparsers})")
+        self.logger.debug(f"create_subparser(subparsers)")
         init_parser = subparsers.add_parser(self.COMMAND, help="Commands related to initializing the workspace")
         init_parser_subparser = init_parser.add_subparsers(dest="action")
 
@@ -16,11 +15,11 @@ class InitArgumentParser:
         project_parser.add_argument("-n", "--name", required=True, help="Name of the project")
 
     def run_action(self, args):
-        self.logger.debug(f"run_action(args: {args})")
+        self.logger.debug(f"run_action(args)")
         if args.command != self.COMMAND:
             return
         if args.action == "project":
             InitController(args.name).init_project()
         else:
-            print(f"Error: Invalid {args.command} action. Use `hape {args.command} --help` for more details.")
+            self.logger.error(f"Error: Invalid action {args.action} for {args.command}. Use `hape {args.command} --help` for more details.")
             exit(1)
